#
# spec file for package python-amqpstorm
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-amqpstorm
Version:        2.7.2
Release:        bp155.2.9
Summary:        Thread-safe Python RabbitMQ Client & Management library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/eandersson/amqpstorm
Source:         https://files.pythonhosted.org/packages/source/A/AMQPStorm/AMQPStorm-%{version}.tar.gz
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose-timer}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pamqp >= 2.0.0}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pamqp >= 2.0.0
Requires:       python-requests
BuildArch:      noarch
%if 0%{?suse_version} < 1500
BuildRequires:  python
%endif
%python_subpackages

%description
Thread-safe Python RabbitMQ Client & Management library.

Supports Python 2.7 and Python 3.3+.
Tested against CPython, PyPy and Pyston.
When using a SSL connection, TLSv1 or higher is required.

%prep
%setup -q -n AMQPStorm-%{version}
sed -i -e "s/'pamqp>=2.0.0,<3.0'/'pamqp>=2.0.0'/" setup.py

%build
export LANG="en_US.UTF8"
%python_build

%install
export LANG="en_US.UTF8"
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/amqpstorm
# remove generic named examples from sitelib
%python_expand rm -rf %{buildroot}%{$python_sitelib}/examples

%check
# test_heartbeat_basic_raise_on_missed_heartbeats randomly fails
%python_expand nosetests-%{$python_bin_suffix} -v amqpstorm/tests/unit -e test_heartbeat_basic_raise_on_missed_heartbeats

%files %{python_files}
%license LICENSE
%doc README.rst examples
%{python_sitelib}/*

%changelog
* Thu Jan 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2.7.2
  * Added ability to override client_properties
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.7.1:
  * Fixed Connection close taking longer than intended when using SSL [#75]- Thanks troglas.
  * Fixed an issue with closing Channels taking too long after the server initiated it.
* Fri Jul 19 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Fix build on SLE-12
  + Add python to BuildRequires for suse_version < 1500
* Fri Jun  7 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.7.0
  * Added support for passing your own ssl context
  * Improved logging verbosity on connection failures
  * Fixed occasional error message when closing a SSL connection
* Tue May  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch of randomly failing test:
  * test_heartbeat_basic_raise_on_missed_heartbeats
* Tue Feb  5 2019 Sean Marlow <sean.marlow@suse.com>
- Remove max version requirement on pamqp.
* Tue Feb  5 2019 Sean Marlow <sean.marlow@suse.com>
- Update to 2.6.2
  + Set default TCP Timeout to 10s on UriConnection to match
    Connection.
  + Internal RPC Timeout for Opening and Closing Connections are
    now set to a fixed 30s.
- Update to 2.6.1
  + Fixed minor issue with the last channel id not being available.
- Update to 2.6.0
  + Re-use closed channel ids.
  + Changed Poller Timeout to be a constant.
  + Improved Connection Close performance.
  + Channels is now a publicly available variable in Connections.
- Update to 2.5.0
  + Upgraded pamqp to v2.0.0.
  + Properly wait until the inbound queue is empty when
    break_on_empty is set.
  + Fixed issue with Management queue/exchange declare when the
    passive flag was set to True.
* Thu Sep 13 2018 Tomáš Chvátal <tchvatal@suse.com>
- Do not distribute generic examples folder
* Mon Sep 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.2:
  * Install license file out of the box
* Wed Aug 29 2018 tchvatal@suse.com
- Install license file
- Make sure we run unittests
- State out all the requirements from setup.py and friends
- Drop not really required devel dependency
* Tue Aug 28 2018 sean.marlow@suse.com
- Update to v2.4.1
  + Added client/server negotiation to better determine the
    maximum supported channels and frame size.
  + We now raise an exception if the maximum allowed channel
    count is ever reached.
* Wed Feb  7 2018 sean.marlow@suse.com
- Update to v2.4.0
  + basic.consume now allows for multiple callbacks.
- Update to v.2.3.0
  + Added delivery_tag abd redelivered properties to message.
  + Added support for Management Api Healthchecks.
  + Fixed delivery_tag being set to None by default.
  + Exposed requests verify and certs flags to Management API.
* Thu Dec  7 2017 sean.marlow@suse.com
- Intial release v2.2.2
